@@ -55,7 +55,7 @@ class BaseParser(object):
             k = params[0]
             v = None
 
-        if not params[0] in self.variables:
+        if not k in self.variables:
             if v is not None:
                 self.variables[k] = v
             else:
